#
# spec file for package kak-lsp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kak-lsp
Version:        17.0.1
Release:        1.1
Summary:        Language Server Protocol client for Kakoune
License:        (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR BSL-1.0 OR MIT) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (Apache-2.0 OR MIT OR Zlib) AND (Apache-2.0 OR MIT OR MPL-2.0) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND MIT AND Zlib AND Unlicense
URL:            https://github.com/kakoune-lsp/kakoune-lsp
Source0:        https://github.com/kakoune-lsp/kakoune-lsp/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  zstd
Provides:       kakoune-lsp

%description
kak-lsp is a Language Server Protocol client for Kakoune written in Rust.

%prep
%autosetup -a1 -n kakoune-lsp-%{version}

%build
%{cargo_build} --all-features

%install
%{cargo_install} --all-features
mkdir -p %{buildroot}%{_datadir}/%{name}/{examples,rc}
install -Dm644 %{name}.toml %{buildroot}%{_datadir}/%{name}/examples/
install -Dm644 rc/lsp.kak %{buildroot}%{_datadir}/%{name}/rc/

%files
%defattr(-,root,root,-)
%license UNLICENSE COPYING MIT
%doc     README.asciidoc CHANGELOG.md
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/examples
%dir %{_datadir}/%{name}/rc
%{_datadir}/%{name}/*

%{_bindir}/kak-lsp

%changelog
* Tue May 28 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to 17.0.1:
  * New default server for Nix, nil, replacing rnix-lsp.
  * The gopls usePlaceholders setting now defaults to true in the default config,
    make sure to either add a mapping for lsp-snippets-select-next-placeholders
    or disable snippets.
  * gopls default config has been changed so inlay (type) hints require no
    gopls-specific knobs to turn on. As with other servers, inlay hints are only
    requested when lsp-inlay-hints-enabled is used.
  * The default config for HTML/CSS/JSON has been updated to use
    vscode-{html,css,json}-language-server as server command instead of
    vscode-{html,css,json}-languageserver.
  * Support for watching files (workspace/didChangeWatchedFiles) is now disabled
    by default to avoid performance problems.
  * Inlay code lenses (used by OCaml and Haskell language servers) are now
    shown after the referenced line. This requires Kakoune version >= 2024.
  * lsp-auto-hover-enable no longer takes an argument; that functionality has
    been moved to lsp-auto-hover-buffer-enable, and it no longer magically spawns
    a client.
  * Removed lsp-connect experimental command.
  * New commands jump-{next,previous} (which have also been added to Kakoune)
    replace and deprecate lsp-{next,previous}.
  * lsp-document-symbol no longer renders the same filename in every single
    line. Commands like jump-next and <ret> still work as before.
  * New option lsp_hover_max_info_lines replaces and deprecates
    lsp_hover_max_lines which now defaults to -1 which means
    lsp_hover_max_info_lines is used to control lines of information in the
    hover box.
  * New option lsp_hover_max_diagnostic_lines to limit the lines for diagnostics
    in the hover box.
  * Fix gopls code actions like "Extract function".
  * Various improvements to compatibility with old Kakoune.
  * Fix startup error when both lsp.kak and Kakoune's jump.kak are autoloaded.
* Sun Mar  3 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update specfile:
  * kak-lsp is now called as kakoune-lsp so we add a Provides.
  * update URL of sources.
* Sun Mar  3 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update specfile:
  * top-level folder of extracted source is kakoune-lsp-16.0.0
  * explicit build requirement of cargo
* Sun Mar  3 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 16.0.0:
  * The modeline shows breadcrumbs like somemodule > someclass > somefunction
  to indicate the symbol around the main cursor.
  * lsp-document-symbols now renders symbols in a tree.
  * lsp_auto_show_code_actions (which renders a lightbulb in the modeline)
  now defaults to true.
  * lsp-code-lens can now run the test at cursor with rust-analyzer. Fixes:
  * lsp-inlay-diagnostics no longer jump around when the cursor is moved
  over the diagnostics. To use this feature, use Kakoune version >= 2024
  (not yet release, consider building from source).
  * When LSP integration is enabled, then disabled and enabled again, the
  KakEnd hook failed to ask the server to exit, which has been fixed.
  * lsp-auto-hover-enable now only re-renders hover info when the main
  selection changes. This means that :info is no longer shadowed immediately
  by auto hover.
  * Completion snippets (accessed via lsp-snippets-select-next-placeholders)
  can now be nested, making it possible to cycle through the arguments of
  nested function calls.
  * In some cases, selecting completions provided by rust-analyzer would labels
  with extra characters (like self.some_method(…)) which has been fixed.
  * completionItem.additionalTextEdits are now applied also when the server
  does not support completionItem/resolve.
  * Snippet metacharacters are now properly escaped, removing spurious
  backslashes from inserted completions.
* Mon Dec 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 15.0.1:
  * Additions:
  - Default configuration for Markdown via [marksman](https://github.com/artempyanykh/marksman).
  - Default configuration for Java via [jdtls](https://github.com/eclipse-jdtls/eclipse.jdt.ls).
  * Fixes:
  - Fix regression in "lsp-show-message-error" and friends.
* Wed Nov 22 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 15.0.0:
  * Additions:
  - Support multiple language servers per filetype (#17).
  - The `kak-lsp.toml` format for specifying language servers has changed. The old format is still supported (#686).
  - `lsp-goto-document-symbol` learned to show a preview of the jump target.
  - Default configuration for PureScript and Scala.
  * Fixes:
  - A regression broke resolving completion item documentation when cycling through completion candidates, which has been fixed (#674).
  - New command `lsp-declaration`, implementing `textDocument/declaration`.
- cargo_config is now part of vendored tarball
* Tue Oct 31 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update _service file
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sun Feb 19 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Updates to version 14.2.0:
  * Additions:
  - Default configuration for CMake.
  - If there are no code actions in the main selection, lsp-code-actions will show code actions from anywhere on a selected line, to make it easier to perform quick-fixes.
  - If requested by the language server, kak-lsp will recursively watch the entire root directory for file changes and forward them to the server via workspace/didChangeWatchedFiles (#649).
  - kak-lsp now asks the server to cancel stale requests (#666).
  - lsp-did-change is async again, which can improve performance (#667).
  - kak-lsp is published to crates.io for easy installation (#660).
  * Fixes:
  - Fix race conditions when spinning up a new server in "kak-lsp --request" (#654), and in "lsp-hover-buffer" (#664).
  - Send inlay hints and semantic tokens only after buffer changes (#663).
- Use zstd compression for vendored dep tarball
* Sat Nov 12 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 14.1.0:
  * Additions:
  - Default language server for protobuf.
  - Added support for `codeAction/resolve`, which allows to use code
    actions sent by Deno for example.
  - The recommended mappings have been augmented by new command
    `lsp-diagnostic-object` to jump to next/previous diagnostics.
  - `lsp-auto-signature-help-enable` now shows an info box by default,
    and formats the active parameter in a bold font.
  - `lsp-definition` and friends now select the symbol name instead of merely
    placing the cursor at symbol start. Same for `lsp-find-error`.
  - `lsp-highlight-references` now selects all references in the current buffer.
  - New `lsp-inlay-code-lenses-enable` command allows to render code
    lenses as virtual text (#623).
  - The support for `filterText` in completions no longer depends on an
    out-of-tree Kakoune feature.
  * Fixes:
  - Fix lags due to `rust-analyzer` sending a ton of progress reports.
  - `lsp-rename` will now write hidden buffers that are affected by the rename,
    to give the language server and other external tools a more consistent
    view of affected files.
  - Suppress "language server not initialized" errors that originate from hooks.
  - Fix a glitch when a line has both a code lens and an inline diagnostic.
  - When talking to servers that don't support UTF-8 byte-offsets, `kak-lsp`
    now adheres to the LSP specification by treating column-offsets
    as UTF-16 Code Units instead of Unicode Code Points.
* Sun Sep 25 2022 socvirnyl.estela@gmail.com
- Update to version 14.0.0:
  * Update changelog for release
  * lsp-goto-document-symbol: map to s instead of <c-o>
  * test: work around "unconfigured filetype" error in tests
  * test: remove unnecessary code for macOS-specific tests
  * Advertise some more LSP capabilities
  * capabilities: minor consistency change
  * clippy
  * lsp-goto-document-symbol: support nested symbols
  * lsp-capabilities: also advertise more commands based on textDocument/documentSymbols
* Tue May 17 2022 socvirnyl.estela@gmail.com
- Update to version 12.2.1:
  * v12.2.1
  * Update changelog for release
  * Test code lens from haskell-language-server
  * lsp-code-lens: pass correct args to lsp-perform-code-lens
  * start new cycle
  * v12.2.0
  * Update changelog for release
  * README: clarify "cargo install" behavior and kak-lsp.toml creation when using plug.kak
  * README: remove misleading warning
  * lsp-hover: limit to 20 lines via lsp_hover_max_lines
* Wed Apr  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for kak-lsp (12.1.0)
